@@ -12,7 +12,11 @@ class Recipe:
         self.buildout, self.name, self.options = buildout, name, options
 
     def install(self):
-        download_dir = self.buildout['buildout']['download-directory']
+        download_dir = self.buildout['buildout'].get('download-directory', \
+            self.buildout['buildout'].get('download-cache', \
+            os.path.join(self.buildout['buildout']['directory'],"downloads")))
+
+        
         version = self.options.get('version')
         if version is None:
             version = '1.21'
